@@ -3,7 +3,7 @@
 //  PRICE
 //
 //  Created by Riccardo Mottola on 2/19/10.
-//  Copyright 2010 Carduus. All rights reserved.
+//  Copyright 2010-2014 Carduus. All rights reserved.
 //
 // This application is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 // This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
@@ -17,9 +17,10 @@
 
 @interface PRPreviewController : NSObject <FilterProgress>
 {
-  IBOutlet NSPanel     *previewWindow;
-  IBOutlet NSButton    *buttContinuous;
-  IBOutlet PRImageView *view;
+  IBOutlet NSPanel       *previewWindow;
+  IBOutlet NSButton      *buttContinuous;
+  IBOutlet PRImageView   *view;
+  IBOutlet NSPopUpButton *scalePopUp;
   
   PRFilterController *filterController;
   
@@ -38,4 +39,7 @@
 - (IBAction)cleanPreview:(id)sender;
 - (IBAction)updatePreview:(id)sender;
 
+- (IBAction)scaleFromMenu:(id)sender;
+
+
 @end
